OppiaMobile Moodle Block Change Log
=====================================

vX - not yet released
--------------------------------------

v2015021800 - released: 18 Feb 2015
--------------------------------------
* https://github.com/DigitalCampus/moodle-block_oppia_mobile_export/issues/issues/issue/122 - save course tags
* https://github.com/DigitalCampus/moodle-block_oppia_mobile_export/issues/issues/issue/121 - make course download link clearer
* https://github.com/DigitalCampus/moodle-block_oppia_mobile_export/issues/issues/issue/123 - allow direct export to OppiaMobile server

v2015011900 - released: 19 Jan 2015
--------------------------------------
* https://github.com/DigitalCampus/moodle-block_oppia_mobile_export/issues/issues/issue/117 - add support for Moodle url activities
* Fix issue with topic ordering in some courses

v2014102900 - released: 29 Oct 2014
--------------------------------------

* Fix https://github.com/DigitalCampus/moodle-block_oppia_mobile_export/issues/issues/issue/115 - preventing media being visible to other apps